<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class simplecache
{
	public function __construct()
	{
		$this->dir 				= APPPATH . "cache/";
		$this->minify 			= true;
		$this->replace->from 	= array("/*","*/");
		$this->replace->with 	= array( sha1("_start_CommentBlock_"), sha1("_commentBlock_End_") );
		$this->filestart 		= "<?php /* SimpleCache v0.0.1 - cached @ " . date("Y-m-d H:i:s") . " */\n/* ";

		$ci =& get_instance();
		$ci->load->helper('url');

		$cache_path = $ci->config->item('simplecache_cache_path');
		$validate_p = $ci->config->item('simplecache_validate_path');
		if ( $cache_path ) 
		{
			if ( $validate_p && ( !is_dir( $cache_path ) || !is_writable( $cache_path ) )  )
			{
				show_error('Please verify that the cache folder <b>' . $cache_path . '</b> is present and that it is writeable.', 500, 'SimpleCache error');
			}
			$this->dir = trim($cache_path,"/") . "/";
		}
	}

	public function set_path( $path = false )
	{
		if ( $path )
		{
			$this->dir = rtrim( $path, "/" ) . "/";
			return true;
		}
		return false;
	}

	public function set_ident( $ident = true )
	{
		$this->ident = $ident;
	}

	public function cache_minify( $minify = false )
	{
		$this->minify = $minify;
	}

	public function set_cache( $ident = false, $data = false )
	{
		if ( !$ident )
		{
			return false;
		}

		$file = $this->dir . url_title( $ident, "underscore" ) . EXT;

		if ( is_file( $file ) )
		{
			@unlink( $file );
		}
		$data = str_replace( $this->replace->from, $this->replace->with, $data );
		if ( $this->minify )
		{
			$data = str_replace( array("\n","\r","\t"), "", $data );
			$data = str_replace("> <","><", $data );
		}
		
		if( !@file_put_contents( $file, $this->filestart . serialize( $data )  ) )
		{
			show_error('Unable to cache "' . $ident . '" to <b>' . $this->dir . '</b>.', 500, 'SimpleCache Error');
		}
		return true;
	}

	public function get_cache( $ident = false, $timeout = "1 week" )
	{
		if ( !$ident ) 
		{
			return false;
		}

		$file = $this->dir . url_title( $ident, "underscore" ) . EXT;

		/** CACHE EXPIRED ? */
			if ( $timeout && !is_numeric( $timeout ) )
			{
				if ( is_file( $file ) )
				{
					$edit 		= date("r", filemtime( $file ) );
					$timestamp 	= strtotime( date("r", strtotime( $edit ) ) . "+" . $timeout );
					if ( time() > strtotime( date('r', $timestamp ) ) )
					{
						!@unlink( $file );
						return false;
					}
				}
			}

		if ( is_file( $file ) )
		{
			$data = @file_get_contents( $file );
			if ( $data && strlen( $data ) > 0 )
			{
				$data  	= substr( $data, strlen( $this->filestart ) );
				$out 	= @unserialize( $data );
				if ( $out )
				{
					return str_replace( $this->replace->with, $this->replace->from, $out );
				}
			}
		}
		return false;
	}
}
